@@ -111,11 +111,11 @@ if sys.version_info >= (3, 8):
 elif sys.version_info >= (3, 7):
     logger.info(f"Python {sys.version_info} == 3.7.x. Defining get_origin, get_args ")
     # 3.7 `List.__origin__ == list`
-    get_origin, get_args = lambda tp: vars(tp).get('__origin__'), lambda tp: vars(tp).get('__args__') if vars(tp).get('__args__') else ()  # noqa: E731
+    get_origin, get_args = lambda tp: getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())  # noqa: E731
 elif sys.version_info >= (3, 6):
     logger.info(f"Python {sys.version_info} == 3.6.x. Defining get_origin, get_args ")
     # 3.6 `List.__origin__ == List`, `Optional` does not have `__dict__`
-    get_origin, get_args = lambda tp: vars(tp).get('__orig_bases__')[0], lambda tp: getattr(tp, '__args__') if hasattr(tp, '__args__') else ()  # noqa: E731
+    get_origin, get_args = lambda tp: getattr(tp, '__extra__', ()) or getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())  # noqa: E731
 else:
     try:
         warnings.warn(f"Unsupported and untested python version {sys.version_info} < 3.6. "
@@ -304,7 +304,8 @@ class ArgSuite(Generic[ArgType]):
 
         :param arg_class: Decorated class
         :param args: Optional positional argument, to be parsed to the arg_class type.
-               `args[0]`: a optional marker to mark the sub-sequence of `argv` to be parsed by the parser. ``None`` will be interpreted as ``sys.argv[1:]``
+               `args[0]`: a optional marker to mark the sub-sequence of `argv` to be parsed by the parser. ``None`` will
+                be interpreted as ``sys.argv[1:]``
                `args[1]`: default to `None`, indicating using the default separator for the argument class
 
         :type `(Optional[Sequence[str]], Optional[str])`
@@ -312,13 +313,13 @@ class ArgSuite(Generic[ArgType]):
         logger.info(f"Patched new for {arg_class} is called with {args} and {kwargs}.")
         if args:
             # TODO Exception handling with helpful error message
-            if (len(args) > 2 or not isinstance(args[0], Sequence) or any(a.__class__ is not str for a in args[0])
-                    or len(args) == 2 and args[1].__class__ not in (NoneType, str)):
-                raise SmartArgError(f"Calling '{arg_class}({args}, {kwargs})' is not allowed:\n"
-                                    f"Only accept positional arguments to parse to the NamedTuple '{arg_class}', but got '{args}'\n"
-                                    f"Use keyword arguments only to create NamedTuple object directly, got '{kwargs}'.")
-            assert arg_class is self._arg_class, (f"{arg_class}: Only the patched root argument class {self._arg_class} "
-                                                  f"allows using positional arguments for parsing.")
+            if (kwargs or len(args) > 2 or len(args) == 2 and args[1].__class__ not in (NoneType, str)
+                    or not (args[0] is None or isinstance(args[0], Sequence) and all(a.__class__ is str for a in args[0]))):
+                raise SmartArgError(f"Calling '{arg_class}(positional {args}, keyword {kwargs})' is not allowed:\n"
+                                    f"Only accept positional arguments to parse to the NamedTuple '{arg_class}'\n"
+                                    f"keyword arguments can only be used to create NamedTuple object directly.")
+            assert arg_class is self._arg_class, (f"{arg_class}: Only the patched root argument class {self._arg_class}"
+                                                  f" allows using positional arguments for parsing.")
             return self.parse_to_arg(*args)
         else:
             try:
@@ -383,7 +384,7 @@ class ArgSuite(Generic[ArgType]):
             if self.is_arg_type(t):
                 self._validate_fields(t)
         # empty namedtuple to extract all the fields.
-        EmptyTup = NamedTuple('EmptyTup')  # type: ignore
+        class EmptyTup(NamedTuple): pass  # noqa: E701
         # note: NamedTuple fields without type won't be regarded as a property/entry _fields.
         arg_fields = arg_class._fields
         invalidate_fields = list(filter(lambda s: s.endswith('_'), arg_fields))
@@ -558,9 +559,8 @@ class ArgSuite(Generic[ArgType]):
 
     def _gen_cmd_argv(self, args: ArgType, prefix) -> Iterable[str]:
         for name, arg in args._asdict().items():
-            if arg is None:
-                assert get_origin(args.__class__._field_types[name]) == Union, f"Field {name} should not be None"
-            else:
+            default = args.__class__._field_defaults.get(name, DefaultMarker)
+            if arg != default:
                 handler, action = self.handler_actions[f'{prefix}{name}']
                 yield from handler.gen_cli_arg(action, arg) if handler else self._gen_cmd_argv(arg, f'{prefix}{name}.')
 
